# eqr

Epistemic Quantile Regression (EQR)

Go here for [Documentation](https://spacetimekhantinuum.gitlab.io/eqr/).

## Notes

To use [lightgbm](https://github.com/microsoft/LightGBM/tree/master/python-package) python package
on Mac you might need to do sometihng like `brew install libomp`.
